pub enum CookieDomain {
HostOnly(String),
Suffix(String),
NotPresent,
Empty,
}Expand description
The domain of a Cookie
Variants
HostOnly(String)
No Domain attribute in Set-Cookie header
Suffix(String)
Domain attribute from Set-Cookie header
NotPresent
Domain attribute was not present in the Set-Cookie header
Empty
Domain attribute-value was empty; technically undefined behavior, but suggested that this be treated as invalid
Implementations
Sourceimpl CookieDomain
The concept of a domain match per IETF RFC6265 Section
5.1.3
impl CookieDomain
The concept of a domain match per IETF RFC6265 Section 5.1.3
Sourcepub fn host_only(request_url: &Url) -> Result<CookieDomain, CookieError>
pub fn host_only(request_url: &Url) -> Result<CookieDomain, CookieError>
Get the CookieDomain::HostOnly variant based on request_url. This is the effective behavior of
setting the domain-attribute to empty
Sourcepub fn matches(&self, request_url: &Url) -> bool
pub fn matches(&self, request_url: &Url) -> bool
Tests if the given url::Url meets the domain-match criteria
Sourcepub fn host_is_identical(&self, request_url: &Url) -> bool
pub fn host_is_identical(&self, request_url: &Url) -> bool
Tests if the given url::Url has a request-host identical to the domain attribute
Sourcepub fn is_public_suffix(&self, psl: &List) -> bool
pub fn is_public_suffix(&self, psl: &List) -> bool
Tests if the domain-attribute is a public suffix as indicated by the provided
publicsuffix::List.